##  Stakeholder Management, Team Dashboards, and Persona Dashboard
Important features:
  * Welcome message to address stakeholders directly
Welcome them to the workspace, explain to them what they see on the dashboard, eventually what is required of them or what they are asked to do, and if applicable links to further resources, training material and so on.
  * Find reports and fact sheet charts that answer the stakeholders key questions,
eg. a CIO might ask:
    * How do I increase revenue?
    * How do I reduce cost?
    * How do I manage risk?
  * Use filtered and saved reports as well as fact sheet charts that show the overall health of the EA program
  * Include a To Do Panel, so users are being led directly to their open tasks


### Example: Project Dashboard
  * Welcome message with an introduction to projects and this dashboard, including important links
  * Project portfolio report to display project risk and business value
  * Roadmap reports on companies' projects
  * Fact sheet chart to display projects to keep
  * Fact sheet chart on strategic importance of projects


**Note**
In this example the fact sheet chart is making use of the tag group “Projects to keep” with 2 Tags (Large benefit, marginal benefit) and the tag group "Group Technology Strategy Objectives" with 3 Tags (Company Project, Foundational Project, Group Project).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b08e87a441014be12ed66fe7e0e36_LowRes.png)
